@@ -3,4 +3,10 @@
 from config2py.s_configparser import *
 from config2py.tools import *
 from config2py.base import get_config
-from config2py.util import ask_user_for_input, Configs, configs, get_configs_local_store
+from config2py.util import (
+    ask_user_for_input,
+    Configs,
+    configs,
+    get_configs_local_store,
+    get_app_data_folder,
+)
